@@ -1,3 +1,9 @@
+"""
+Welcome to PyTabular.
+__init__.py will start to setup the basics.
+It will setup logging and make sure Pythonnet is good to go.
+Then it will begin to import specifics of the module.
+"""
 # flake8: noqa
 import logging
 import os
@@ -49,10 +55,10 @@ logger.info("Importing specifics in module...")
 from .pytabular import Tabular
 
 from .basic_checks import (
-    Return_Zero_Row_Tables,
-    Table_Last_Refresh_Times,
     BPA_Violations_To_DF,
     Last_X_Interval,
+    Return_Zero_Row_Tables,
+    Table_Last_Refresh_Times,
 )
 from .logic_utils import (
     pd_dataframe_to_m_expression,
