@@ -1,3 +1,7 @@
+"""
+`pytabular.py` is where it all started. So there is a lot of old methods that will eventually be deprecated.
+Main class is `Tabular()`. Use that for connecting with your models.
+"""
 import logging
 
 from Microsoft.AnalysisServices.Tabular import (
@@ -9,7 +13,6 @@ from Microsoft.AnalysisServices.Tabular import (
     MPartitionSource,
 )
 
-from Microsoft.AnalysisServices import UpdateOptions
 from typing import List, Union
 from collections import namedtuple
 import pandas as pd
@@ -67,7 +70,7 @@ class Tabular(PyObject):
                 for database in self.Server.Databases.GetEnumerator()
                 if database.Name == self.Catalog or self.Catalog is None
             ][0]
-        except Exception:
+        except Exception:  # pragma: no cover
             err_msg = f"Unable to find Database... {self.Catalog}"
             logger.error(err_msg)
             raise Exception(err_msg)
@@ -149,15 +152,17 @@ class Tabular(PyObject):
         _jobs_df = self.Query("select * from $SYSTEM.DISCOVER_JOBS")
         return len(_jobs_df[_jobs_df["JOB_DESCRIPTION"] == "Process"]) > 0
 
-    def Disconnect(self) -> bool:
-        """Disconnects from Model
-
-        Returns:
-                bool: True if successful
-        """
+    def Disconnect(self) -> None:
+        """Disconnects from Model"""
         logger.info(f"Disconnecting from - {self.Server.Name}")
+        atexit.unregister(self.Disconnect)
         return self.Server.Disconnect()
 
+    def Reconnect(self) -> None:
+        """Reconnects to Model"""
+        logger.info(f"Reconnecting to {self.Server.Name}")
+        return self.Server.Reconnect()
+
     def Refresh(self, *args, **kwargs) -> pd.DataFrame:
         """PyRefresh Class to handle refreshes of model.
 
@@ -174,20 +179,17 @@ class Tabular(PyObject):
         """
         return self.PyRefresh(self, *args, **kwargs).Run()
 
-    def Update(self, UpdateOptions: UpdateOptions = UpdateOptions.ExpandFull) -> None:
-        """[Update Model](https://docs.microsoft.com/en-us/dotnet/api/microsoft.analysisservices.majorobject.update?view=analysisservices-dotnet#microsoft-analysisservices-majorobject-update(microsoft-analysisservices-updateoptions))
-
-        Args:
-                UpdateOptions (UpdateOptions, optional): See above MS Doc link. Defaults to UpdateOptions.ExpandFull.
-
-        Returns:
-                None: Placeholder to eventually change.
+    def SaveChanges(self):
+        """Called after refreshes or any model changes.
+        Currently will return a named tuple of all changes detected. However a ton of room for improvement here.
         """
-        logger.debug("Running Update Request")
-        return self.Database.Update(UpdateOptions)
+        if self.Server.Connected is False:
+            self.Reconnect()
 
-    def SaveChanges(self) -> bool:
         def property_changes(Property_Changes):
+            """
+            Returns any property changes.
+            """
             Property_Change = namedtuple(
                 "Property_Change",
                 "New_Value Object Original_Value Property_Name Property_Type",
@@ -237,8 +239,9 @@ class Tabular(PyObject):
                 Xmla_Results,
             )
 
-    def Backup_Table(self, table_str: str) -> bool:
-        """USE WITH CAUTION, EXPERIMENTAL. Backs up table in memory, brings with it measures, columns, hierarchies, relationships, roles, etc.
+    def Backup_Table(self, table_str: str) -> bool:  # pragma: no cover
+        """Will be removed. This is experimental with no written pytest for it.
+        Backs up table in memory, brings with it measures, columns, hierarchies, relationships, roles, etc.
         It will add suffix '_backup' to all objects.
         Refresh is performed from source during backup.
 
@@ -254,6 +257,7 @@ class Tabular(PyObject):
         logger.info("Beginning Renames")
 
         def rename(items):
+            """Iterates through items and requests rename."""
             for item in items:
                 item.RequestRename(f"{item.Name}_backup")
                 logger.debug(f"Renamed - {item.Name}")
@@ -294,6 +298,7 @@ class Tabular(PyObject):
             self.Model.Relationships.Add(relationship)
 
         def clone_role_permissions():
+            """Clones the role permissions for table."""
             logger.info("Beginning to handle roles and permissions for table...")
             logger.debug("Finding Roles...")
             roles = [
@@ -336,8 +341,8 @@ class Tabular(PyObject):
         self.SaveChanges()
         return True
 
-    def Revert_Table(self, table_str: str) -> bool:
-        """USE WITH CAUTION, EXPERIMENTAL. This is used in conjunction with Backup_Table().
+    def Revert_Table(self, table_str: str) -> bool:  # pragma: no cover
+        """Will be removed. This is experimental with no written pytest for it. This is used in conjunction with Backup_Table().
         It will take the 'TableName_backup' and replace with the original.
         Example scenario ->
         1. model.Backup_Table('TableName')
@@ -372,6 +377,9 @@ class Tabular(PyObject):
         ]
 
         def remove_role_permissions():
+            """
+            Removes role permissions from table.
+            """
             logger.debug(
                 f"Finding table and column permission in roles to remove from {table_str}"
             )
@@ -405,6 +413,9 @@ class Tabular(PyObject):
         remove_role_permissions()
 
         def dename(items):
+            """
+            Denames all items.
+            """
             for item in items:
                 logger.debug(f"Removing Suffix for {item.Name}")
                 item.RequestRename(remove_suffix(item.Name, "_backup"))
@@ -449,7 +460,8 @@ class Tabular(PyObject):
         if Effective_User is None:
             return self.Adomd.Query(Query_Str)
 
-        try:
+        try:  # pragma: no cover
+            # This needs a public model with effective users to properly test
             conn = self.Effective_Users[Effective_User]
             logger.debug(f"Effective user found querying as... {Effective_User}")
         except Exception:
@@ -462,7 +474,7 @@ class Tabular(PyObject):
     def Query_Every_Column(
         self, query_function: str = "COUNTROWS(VALUES(_))"
     ) -> pd.DataFrame:
-        """This will dynamically create a query to pull all columns from the model and run the query function. It will replace the _ with the column to run.
+        """Will be removed. Use `Query_All()` in your `PyColumns` instead. This will dynamically create a query to pull all columns from the model and run the query function. It will replace the _ with the column to run.
         Args:
                 query_function (str, optional): Dax query is dynamically building a query with the UNION & ROW DAX Functions.
         Returns:
@@ -486,7 +498,7 @@ class Tabular(PyObject):
         return self.Query(query_str)
 
     def Query_Every_Table(self, query_function: str = "COUNTROWS(_)") -> pd.DataFrame:
-        """This will dynamically create a query to pull all tables from the model and run the query function.
+        """Will be removed. Use `Query_All()` in your `PyTables` instead. This will dynamically create a query to pull all tables from the model and run the query function.
         It will replace the _ with the table to run.
         Args:
                 query_function (str, optional): Dax query is dynamically building a query with the UNION & ROW DAX Functions. Defaults to 'COUNTROWS(_)'.
